/*  ********************************************************************** */
/*  *************** ATTENTION ******************************************** */
/*  ********************************************************************** */

/* Please read to comments. Especially important are the comments 
that are marked with "ATTENTION" as this one. In short:

1. You need to have two stata-commands available that are not 
in the base distribution of stata (unique, tabmiss)

2. You need to adjust all paths that apper below

3. You need to use the .tex-file that contains the table properly. 

If you are working with my example files, you only need to adjust the path to 
the working directory for stata .....

*/




#delimit;

/* flush memory */
clear;
/* set memory limit */
set mem 50m;

/*  ********************************************************************** */
/*  *************** ATTENTION ******************************************** */
/*  ********************************************************************** */
/* you need to have the command unique available. If you you do 
not have it installed, remove the comments below: */
/* ssc install unique; */
/* you need to have the command tabmiss available. If you you do 
not have it installed, remove the comments below: */
/* ssc install tabmiss; */


/*  ********************************************************************** */
/*  *************** ATTENTION ******************************************** */
/*  ********************************************************************** */
/* go to working directory - this is the directory 
where you stata-dataset is located*/
cd "~/Desktop/stata_TeX_codebook/";




/* close all open logs */
capture log close;

/* start log using a specified file and format */
log using log.smcl, smcl replace;


/*  ********************************************************************** */
/*  *************** ATTENTION ******************************************** */
/*  ********************************************************************** */
/* load the stata-dataset - here it is assumed that you have a file 
dataset.dta in your working directory */
use "dataset.dta";



/*  ********************************************************************** */
/*  *************** ATTENTION ******************************************** */
/*  ********************************************************************** */
/* The following file open command determines where the .tex-file with the table 
will be saved. In this case, the full path to the file will be

~/Desktop/stata_TeX_codebook/TeX/codebookcompact.tex

But as we already are in the working directory stata_TeX_codebook, the path below 
is shorter. The .tex-table will be in a subfolder /TeX/ and its name is codebookcompact.tex

Adjust according to your needs: */
file open myfile using TeX/codebookcompact.tex, write replace;

/* this defines the header of the table */
file write myfile "\begin{longtable}{"  _n;
file write myfile ">{\hsize=.50\hsize}X"  _n;
file write myfile "|>{\hsize=.1\hsize}X"  _n;
file write myfile ">{\hsize=.15\hsize}X"  _n;
file write myfile ">{\hsize=.25\hsize}X"  _n;
file write myfile ">{\hsize=.15\hsize}X"  _n;
file write myfile ">{\hsize=.15\hsize}X"  _n;
file write myfile ">{\hsize=.15\hsize}X"  _n;
file write myfile "|>{\hsize=.65\hsize}X"  _n;
file write myfile"}"  _n;
file write myfile "\caption[codebook]{codebook} \label{codebook} \\"  _n;
file write myfile "\hline Variable & Obs & Unique & Missing & Mean & Min & Max & Label \\ \hline "  _n;
file write myfile "\endfirsthead"  _n;
file write myfile "\multicolumn{8}{c}%"  _n;
file write myfile "{{\bfseries \tablename\ \thetable{}: codebook -- continued}} \\"  _n;
file write myfile "\hline Variable & Obs & Unique & Missing & mean & Min & Max & Label \\ \hline"  _n;
file write myfile "\endhead"  _n;
file write myfile "\hline \multicolumn{8}{r}{{{\small(continued on next page)}}} \\ \hline"  _n;
file write myfile "\endfoot"  _n;
file write myfile "\hline"  _n;
file write myfile "\endlastfoot"  _n;

/* loop over all variables.  Calculates several entries of the codebook table, saves them 
in a macro and writes the .tex-file line by line .... .*/
quietly describe,simple;

/* Hier statt * eine Variablenliste? */

foreach y of var *{;
	/* take care of LaTeX special in Variablenames */
    local x = subinstr("`y'","_","\_",9);
    /* calculate entries of table */
	unique `y';
	local observ = r(N);
	local unique = r(sum);
	quietly tabmiss `y';
	local missings = r(sum);
	local missingsperc = r(mean)*100;
	/* local missingsperc = round(r(missingsperc),0.1); */
	local missingsperc =  string(`missingsperc',"%9.0f");
	quietly sum `y';
	local mean= round(r(mean),0.1);
	local mean =  string(`mean',"%9.1f");
	local min = r(min);
	local min =  string(`min',"%9.1f");
	local max = round(r(max),0.1);
	local max =  string(`max',"%9.1f");
	local labelofvariable: variable label `y';
	
		
file write myfile " `x' &  `observ' & `unique' & `missings' (`missingsperc' \%) &`mean' & `min' 
& `max' &  `labelofvariable' \medskip \\  " _n;
 	};
/* ende der tex-tabelle schreiben */
file write myfile "\hline"  _n;
file write myfile "\end{longtable}"  _n;
file close myfile; 

/*  ********************************************************************** */
/*  *************** ATTENTION ******************************************** */
/*  ********************************************************************** */
/* Now you have a file codebookcompact.tex (or whatever name you have chosen above).
This can be used in your .tex file. 

DO NOT COPY THE CONTENTS OF THE FILE INTO YOUR .tex file. This is not going to work. 

The proper command is to use the table is 

\LTXtable{\textwidth}{/TeX/codebookcompact.tex}

Again, the path to the file must be correct!

you need to have 
\usepackage{ltxtable}
\usepackage{booktabs} 

in the preamble of you .tex-file.

Usually, it is useful to typeset the table in landscape mode. The TeX-command to include 
the table then is:

\begin{landscape}
\LTXtable{1.5\textheight}{codebookcompact.tex}
\end{landscape}

and you shoud have

\usepackage{lscape}


in the preamble of you .tex-file.

Have a look at /TeX/example.tex where everything is done for you.

Good Luck.

*/




/*  save the stata-log */
translate log.smcl log.ps, replace translator(smcl2ps) headertext(on) pagesize(A4);

/* translate log.smcl log.pdf, replace translator(smcl2pdf); */

translate log.smcl log.txt, replace translator(smcl2txt); 


/* stop logging */
log close;

clear;

exit;
